package com.opensymphony.clickstream;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import java.io.IOException;

/**
 * The filter that keeps track of a new entry in the clickstream for <b>every request</b>.
 *
 * @author <a href="plightbo@hotmail.com">Patrick Lightbody</a>
 */
public class ClickstreamFilter implements Filter {
    private static final Log log = LogFactory.getLog(ClickstreamFilter.class);

    protected FilterConfig filterConfig;
    private final static String FILTER_APPLIED = "_clickstream_filter_applied";

    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain) throws IOException, ServletException {
        // Ensure that filter is only applied once per request.
        if (request.getAttribute(FILTER_APPLIED) == null) {
            if (log.isDebugEnabled()) log.debug("Applying clickstream filter to request.");
            request.setAttribute(FILTER_APPLIED, Boolean.TRUE);

            HttpSession session = ((HttpServletRequest) request).getSession();
            Clickstream stream = (Clickstream) session.getAttribute("clickstream");
            stream.addRequest((HttpServletRequest) request);
        }
        else {
            if (log.isDebugEnabled()) log.debug("Clickstream filter already applied, ignoring it.");
        }

        // pass the request on
        chain.doFilter(request, response);
    }

    public void init(FilterConfig filterConfig) throws ServletException {
        this.filterConfig = filterConfig;
    }

    public void destroy() {
    }
}