package com.opensymphony.clickstream;

import com.opensymphony.clickstream.logger.ClickstreamLoggerFactory;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;
import javax.servlet.http.HttpSession;
import javax.servlet.http.HttpSessionEvent;
import javax.servlet.http.HttpSessionListener;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

/**
 * The listener that keeps track of all clickstreams in the container as well
 * as the creating new Clickstream objects and initiating logging when the
 * clickstream dies (session has been invalidated).
 *
 * @author <a href="plightbo@hotmail.com">Patrick Lightbody</a>
 */
public class ClickstreamListener implements ServletContextListener, HttpSessionListener {
    private static final Log log = LogFactory.getLog(ClickstreamListener.class);

    public static final String CLICKSTREAMS_ATTRIBUTE_KEY = "clickstreams";
    private Map clickstreams = Collections.synchronizedMap(new HashMap());

    public ClickstreamListener() {
        log.debug("ClickstreamLogger constructed");
    }

    public void contextInitialized(ServletContextEvent sce) {
        log.debug("ServletContext Initialised");
        sce.getServletContext().setAttribute(CLICKSTREAMS_ATTRIBUTE_KEY, clickstreams);
    }

    public void contextDestroyed(ServletContextEvent sce) {
    }

    public void sessionCreated(HttpSessionEvent hse) {
        HttpSession session = hse.getSession();
        if (log.isDebugEnabled()) log.debug("Session " + session.getId() + " was created, adding a new clickstream.");
        Clickstream clickstream = new Clickstream();
        session.setAttribute("clickstream", clickstream);
        clickstreams.put(session.getId(), clickstream);
    }

    public void sessionDestroyed(HttpSessionEvent hse) {
        HttpSession session = hse.getSession();
        if (log.isDebugEnabled()) log.debug("Session " + session.getId() + " was destroyed, logging the clickstream and removing it.");
        Clickstream stream = (Clickstream) clickstreams.get(session.getId());

        try {
            if (stream.getSession() != null) {
                ClickstreamLoggerFactory.getLogger().log(stream);
            }
        }
        catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        finally {
            clickstreams.remove(session.getId());
        }
    }
}